@@ -1,6 +1,6 @@
 from sigma.pipelines.sysmon import sysmon_pipeline
 from sigma.pipelines.crowdstrike import crowdstrike_fdr_pipeline
-from sigma.pipelines.splunk import splunk_windows_pipeline, splunk_windows_sysmon_acceleration_keywords
+from sigma.pipelines.splunk import splunk_windows_pipeline, splunk_windows_sysmon_acceleration_keywords, splunk_cim_data_model
 from sigma.pipelines.windows import windows_pipeline
 from sigma.processing.resolver import ProcessingPipelineResolver
 
@@ -9,5 +9,6 @@ pipelines = ProcessingPipelineResolver({
     "crowdstrike_fdr": crowdstrike_fdr_pipeline,
     "splunk_windows": splunk_windows_pipeline,
     "splunk_sysmon_acceleration": splunk_windows_sysmon_acceleration_keywords,
+    "splunk_cim": splunk_cim_data_model,
     "windows": windows_pipeline,
 })
\ No newline at end of file
